@@ -61,6 +61,7 @@ subscript = {
     'a': 'ₐ',
     'e': 'ₑ',
     'i': 'ᵢ',
+    'j': '\N{LATIN SUBSCRIPT SMALL LETTER J}',
     'o': 'ₒ',
     'r': 'ᵣ',
     'u': 'ᵤ',
@@ -633,6 +634,9 @@ transliterators = {
 
 symbols = {
     r'\_': '_',
+    r'\|': '‖',
+    r'\lVert': '‖',
+    r'\rVert': '‖',
     r'\\': '\\',
     r'\aleph': 'ℵ',
     r'\alpha': 'α',
@@ -662,16 +666,13 @@ symbols = {
     r'\boxplus': '⊞',
     r'\boxtimes': '⊠',
     r'\bullet': '•',
-    r'\bullet': '∙',
     r'\bumpeq': '≏',
     r'\Bumpeq': '≎',
     r'\cap': '∩',
     r'\Cap': '⋒',
     r'\cdot': '·',
-    r'\cdot': '⋅',
     r'\cdots': '⋯',
     r'\chi': 'χ',
-    r'\circ': '°',
     r'\circ': '∘',
     r'\circeq': '≗',
     r'\circlearrowleft': '↺',
@@ -680,7 +681,7 @@ symbols = {
     r'\circledcirc': '⊚',
     r'\circleddash': '⊝',
     r'\clubsuit': '♣',
-    r'\clubsuit': '♧',
+    r'\varclubsuit': '♧',
     r'\complement': '∁',
     r'\cong': '≅',
     r'\cup': '∪',
@@ -700,12 +701,11 @@ symbols = {
     r'\ddots': '⋱',
     r'\ddotsup': '⋰',
     r'\defeq': '≝',
-    r'\Delta': '∆',
     r'\delta': 'δ',
     r'\Delta': 'Δ',
     r'\diamond': '⋄',
     r'\diamondsuit': '♢',
-    r'\diamondsuit': '♦',
+    r'\vardiamondsuit': '♦',
     r'\div': '÷',
     r'\divideontimes': '⋇',
     r'\doteq': '≐',
@@ -745,13 +745,13 @@ symbols = {
     r'\gtrsim': '≳',
     r'\hbar': 'ℏ',
     r'\heartsuit': '♡',
-    r'\heartsuit': '♥',
+    r'\varheartsuit': '♥',
     r'\hookleftarrow': '↩',
     r'\hookrightarrow': '↪',
     r'\iiint': '∭',
     r'\iint': '∬',
     r'\Im': 'ℑ',
-    r'\in': '∊',
+    r'\in': '∈',
     r'\infty': '∞',
     r'\int': '∫',
     r'\intercal': '⊺',
@@ -795,7 +795,6 @@ symbols = {
     r'\mid': '∣',
     r'\models': '⊨',
     r'\mp': '∓',
-    r'\mu': 'µ',
     r'\multimap': '⊸',
     r'\multimapdotbothA': '⊶',
     r'\multimapdotbothB': '⊷',
@@ -809,7 +808,6 @@ symbols = {
     r'\ngeq': '≱',
     r'\ngtr': '≯',
     r'\ni': '∋',
-    r'\ni': '∍',
     r'\nleftarrow': '↚',
     r'\nLeftarrow': '⇍',
     r'\nleftrightarrow': '↮',
@@ -841,7 +839,6 @@ symbols = {
     r'\oint': '∮',
     r'\omega': 'ω',
     r'\Omega': 'Ω',
-    r'\Omega': 'Ω',
     r'\ominus': '⊖',
     r'\oplus': '⊕',
     r'\oslash': '⊘',
@@ -883,7 +880,7 @@ symbols = {
     r'\rtimes': '⋊',
     r'\S': '§',
     r'\searrow': '↘',
-    r'\searrow': '↙',
+    r'\swarrow': '↙',
     r'\setminus': '∖',
     r'\sharp': '♯',
     r'\sigma': 'σ',
@@ -891,7 +888,7 @@ symbols = {
     r'\sim': '∼',
     r'\simeq': '≃',
     r'\spadesuit': '♠',
-    r'\spadesuit': '♤',
+    r'\varspadesuit': '♤',
     r'\sphericalangle': '∢',
     r'\sqcap': '⊓',
     r'\sqcup': '⊔',
@@ -899,13 +896,6 @@ symbols = {
     r'\sqsubseteq': '⊑',
     r'\sqsupset': '⊐',
     r'\sqsupseteq': '⊒',
-    r'\stackrel': '∸',
-    r'\stackrel': '≘',
-    r'\stackrel': '≙',
-    r'\stackrel': '≚',
-    r'\stackrel': '≛',
-    r'\stackrel': '≞',
-    r'\stackrel': '≟',
     r'\star': '⋆',
     r'\subset': '⊂',
     r'\Subset': '⋐',
@@ -944,7 +934,6 @@ symbols = {
     r'\varphi': 'ϕ',
     r'\varpi': 'ϖ',
     r'\varrho': 'ϱ',
-    r'\varsigma': 'ϛ',
     r'\varsigma': 'ς',
     r'\vartheta': 'ϑ',
     r'\vdash': '⊢',
